@@ -1,7 +1,6 @@
 #' @title Farthest First Clustering Learner
 #'
-#' @name mlr_learners_clust.FF
-#' @include LearnerClust.R
+#' @name mlr_learners_clust.ff
 #'
 #' @description
 #' A [LearnerClust] for Farthest First clustering implemented in [RWeka::FarthestFirst()].
@@ -10,26 +9,22 @@
 #'
 #' @templateVar id clust.ff
 #' @template learner
-#' @examples
-#' \dontrun{
-#' if (requireNamespace("RWeka")) {
-#'   learner = mlr3::lrn("clust.ff")
-#'   print(learner)
 #'
-#'   # available parameters:
-#'   learner$param_set$ids()
-#' }}
+#' @references
+#' `r format_bib("witten2002data", "hochbaum1985best")`
 #'
 #' @export
+#' @template seealso_learner
+#' @template example
 LearnerClustFarthestFirst = R6Class("LearnerClustFF",
   inherit = LearnerClust,
   public = list(
     #' @description
     #' Creates a new instance of this [R6][R6::R6Class] class.
     initialize = function() {
-      ps = ps(
-        N = p_int(default = 2L, lower = 1L, tags = "train"),
-        S = p_int(default = 1L, lower = 1L, tags = "train"),
+      param_set = ps(
+        N = p_int(1L, default = 2L, tags = "train"),
+        S = p_int(1L, default = 1L, tags = "train"),
         output_debug_info = p_lgl(default = FALSE, tags = "train")
       )
 
@@ -37,14 +32,14 @@ LearnerClustFarthestFirst = R6Class("LearnerClustFF",
         id = "clust.ff",
         feature_types = c("logical", "integer", "numeric"),
         predict_types = "partition",
-        param_set = ps,
+        param_set = param_set,
         properties = c("partitional", "exclusive", "complete"),
         packages = "RWeka",
+        man = "mlr3cluster::mlr_learners_clust.ff",
         label = "Farthest First Clustering"
       )
     }
   ),
-
   private = list(
     .train = function(task) {
       pv = self$param_set$get_values(tags = "train")
@@ -64,3 +59,6 @@ LearnerClustFarthestFirst = R6Class("LearnerClustFF",
     }
   )
 )
+
+#' @include aaa.R
+learners[["clust.ff"]] = LearnerClustFarthestFirst
