@@ -1,8 +1,6 @@
 #' @title Gaussian Mixture Models-Based Clustering Learner
 #'
 #' @name mlr_learners_clust.mclust
-#' @include LearnerClust.R
-#' @include aaa.R
 #'
 #' @description
 #' A [LearnerClust] for model-based clustering implemented in [mclust::Mclust()].
@@ -11,65 +9,33 @@
 #'
 #' @templateVar id clust.mclust
 #' @template learner
-#' @template example
+#'
+#' @references
+#' `r format_bib("scrucca2016mclust", "fraley2002model")`
 #'
 #' @export
+#' @template seealso_learner
+#' @template example
 LearnerClustMclust = R6Class("LearnerClustMclust",
   inherit = LearnerClust,
   public = list(
     #' @description
     #' Creates a new instance of this [R6][R6::R6Class] class.
     initialize = function() {
-      ps = ps(
-        G = p_uty(default = c(1:9), custom_check = function(x) {
-          if (test_numeric(x)) {
-            return(TRUE)
-          } else {
-            stop("`G` need to be a numeric vector")
-          }
-        }, tags = "train"),
-        modelNames = p_uty(custom_check = function(x) {
-          if (test_character(x)) {
-            return(TRUE)
-          } else {
-            stop("`modelNames` need to be a character vector")
-          }
-        }, tags = "train"),
-        prior = p_uty(custom_check = function(x) {
-          if (test_list(x)) {
-            return(TRUE)
-          } else {
-            stop("`prior` need to be a list")
-          }
-        }, tags = "train"),
-        control = p_uty(default = mclust::emControl(), custom_check = function(x) {
-          if (test_list(x)) {
-            return(TRUE)
-          } else {
-            stop("`control` need to be a list of control parameters for EM")
-          }
-        }, tags = "train"),
-        initialization = p_uty(custom_check = function(x) {
-          if (test_list(x)) {
-            return(TRUE)
-          } else {
-            stop("`initialization` need to be a list of initialization components")
-          }
-        }, tags = "train"),
-        x = p_uty(custom_check = function(x) {
-          if (test_class(x, "mclustBIC")) {
-            return(TRUE)
-          } else {
-            stop("`x` need to be an object of class 'mclustBIC'")
-          }
-        }, tags = "train")
+      parma_set = ps(
+        G = p_uty(default = 1:9, tags = "train", custom_check = check_numeric),
+        modelNames = p_uty(tags = "train", custom_check = check_character),
+        prior = p_uty(tags = "train", custom_check = check_list),
+        control = p_uty(default = mclust::emControl(), tags = "train", custom_check = check_list),
+        initialization = p_uty(tags = "train", custom_check = check_list),
+        x = p_uty(tags = "train", custom_check = crate(function(x) check_class(x, "mclustBIC")))
       )
 
       super$initialize(
         id = "clust.mclust",
         feature_types = c("logical", "integer", "numeric"),
         predict_types = c("partition", "prob"),
-        param_set = ps,
+        param_set = parma_set,
         properties = c("partitional", "fuzzy", "complete"),
         packages = "mclust",
         man = "mlr3cluster::mlr_learners_clust.mclust",
@@ -77,7 +43,6 @@ LearnerClustMclust = R6Class("LearnerClustMclust",
       )
     }
   ),
-
   private = list(
     .train = function(task) {
       pv = self$param_set$get_values(tags = "train")
@@ -100,4 +65,5 @@ LearnerClustMclust = R6Class("LearnerClustMclust",
   )
 )
 
+#' @include aaa.R
 learners[["clust.mclust"]] = LearnerClustMclust
