@@ -1,17 +1,13 @@
-context("clust.hclust")
-
 test_that("autotest", {
   learner = mlr3::lrn("clust.hclust")
   expect_learner(learner)
-
   result = run_autotest(learner)
   expect_true(result, info = result$error)
 })
 
-
 test_that("Learner properties are respected", {
   task = tsk("usarrests")
-  learner = mlr_learners$get("clust.hclust")
+  learner = lrn("clust.hclust")
   expect_learner(learner, task)
 
   # test on multiple paramsets
